%define _with_ffms2 1
#
# spec file for package aegisub
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffms2

Name:           aegisub
Version:        3.0.4
Release:        22.8
Summary:        Subtitle editor
License:        BSD-3-Clause
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://www.aegisub.net/
Source0:        http://ftp.aegisub.org/pub/releases/aegisub-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  pkg-config >= 0.20
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
BuildRequires:  wxWidgets-devel >= 2.9.3
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3) >= 3.3
BuildRequires:  pkgconfig(fontconfig) >= 2.4
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(hunspell) >= 1.2.0
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libpulse) >= 0.5
BuildRequires:  pkgconfig(lua) < 5.2
BuildRequires:  pkgconfig(lua) >= 5.1
BuildRequires:  pkgconfig(zlib)
%if %{with ffms2}
BuildRequires:  pkgconfig(ffms2)
%endif

%description
Aegisub is an advanced subtitle editor for Windows, and UNIX-like systems, such
as Linux, Mac OS X and BSD. It is open source software and free for any use.

Aegisub natively works with the Advanced SubStation Alpha format (aptly
abbreviated ASS) which allows for many advanced effects in the subtitles, apart
from just basic timed text. Aegisub's goal is to support using these advanced
functions with ease.

%prep
%setup -q -n aegisub
rm -r contrib docs
cd aegisub
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/version.cpp
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/version.cpp

%build
cd aegisub
# Don't use --disable-update-checker because of http://blog.aegisub.org/2012/02/bit-of-statistics.html
%configure --with-player-audio=PulseAudio \
           --without-oss
make %{?_smp_mflags}

%install
cd aegisub
%make_install
%find_lang %{name}-30

%files -f aegisub/%{name}-30.lang
%defattr(0644, root, root, 0755)
%doc aegisub/LICENCE
%attr(0755,root,root) %{_bindir}/aegisub-3.0
%{_datadir}/aegisub/
%{_datadir}/applications/aegisub.desktop
%{_datadir}/icons/hicolor/*/apps/aegisub.*

%changelog
* Sun Jul  7 2013 reddwarf@opensuse.org
- Update to 3.0.4
  * Update Basque translation
* Mon Jul  1 2013 reddwarf@opensuse.org
- Update to 3.0.3
  * Fix crash when playing audio before time 0
  * Round syllable durations to centiseconds when splitting syllables
  * Save the horizontal zoom correctly
  * Fix bug where FloatEdit controls would sometimes not report the selected value
  * Actually select the correct things in the Select Overlaps macro
  * Give temporary files proper extensions to make it easier to open them when something goes wrong
  * Show an error message when writing a file fails
  * Fix reading subtitles from Matroska
  * Fix a case where unicode characters would result in inconsistent and baffling errors when loading Lua scripts
  * Fix loading non-ascii actor names from plain-text files
  * Obey the option for setting the number of recently opened subtitle files to remember
  * Use Lua 5.1 when both it and 5.2 are available
  * Commit pending audio changes on Enter in the edit box
  * Add Dutch translation
  * Update Finnish translation
  * Update Arabic translation
  * Fix some cases where the detached video dialog would get set to bogus sizes
  * Add .m4v to the list of video file extensions
  * Fix loading y4m files
  * Release mouse capture from the visual tools when the zoom is changed
* Tue Oct 23 2012 reddwarf@opensuse.org
- Removed aegisub-3.0.0-docdir.patch and aegisub-3.0.0-no_glu.patch,
  they have been applied upstream
- Update to 3.0.2
  * Allow framerate transform to/from variable without external timecodes loaded (#1530)
  * Honor the configured limits for the find/replace history (#1528)
  * Fix occassional non-error dialog when running multiple copies of Aegisub
  * Fix bug that sometimes resulted in later karaoke syllables moving when early ones were modified
  * Truncate overly long syllables rather than adjusting all of the other syllables to make them fit
  * Play right-clicked syllables
  * Fix splitting lines by karaoke (#1541)
  * Remove dependency on glu
  * Honor docdir and localedir configuration variables
  * Make it possible to type style names again
  * Break undo grouping after 30 seconds of inactivity rather than 10
  * Switch the Duration field back to time mode when video is closed
  * Save a single wav containing all selected lines rather than a separate wav for each line with "Create audio clip"
  * Make pasting lines not horrible slow (#1534)
  * Make the correct row visible when selecting rows with shift + arrow keys in the grid (#1533)
  * Fix a few errors in the German translation (#1523)
  * Update Czech translation
  * Update Indonesian translation
  * Update Hungarian translation
  * Add partial Arabic translation (#1532)
* Mon Oct  8 2012 reddwarf@opensuse.org
- Update to 3.0.1
  * Updated Russian translation
  * Updated Greek translation
  * Partially update Finnish translation
  * Fixed some errors in the Portuguese translation
  * Fix packaging issues with the Serbian translation
  * Update the size of the karaoke syllable bar when the window is resized
  * Add scroll arrows to the karaoke syllable bar when the contents are too wide to fit
  * Change the color of the karaoke syllable split cursor to indicate whether it'll add or remove a split
  * Increase the hit area for removing karaoke splits a little
  * Remove the correct split when clicking to the left of a split line
  * Re-add the "Play current line" button to the audio toolbar
  * Stop video playback when the stop button is clicked in the audio toolbar as 2.1.9 did
  * Scroll the audio display after a click near an edge when auto-scrolling is enabled
  * Recenter the audio display if a newly selected line is very close to an edge in addition to if it's not fully onscreen, as 2.1 did
  * Fix subtitle timing issues after loading a timecodes file
  * Fix rounding error that resulted in 30000/1001 FPS video being treated as 30001/1001 FPS
* Sun Oct  7 2012 reddwarf@opensuse.org
- Update to 3.0.0
  * The audio display and related things such as the karaoke
    syllable splitting interface have been rewritten from scratch.
    The spectograph rendering is now much higher quality and
    faster, and many new features have been added.
  * Changes made in the main edit box and surrounding controls no
    longer have to be committed. Instead, changes are made to the
    file as you type, with the video display updating in real time.
  * See http://www.aegisub.org/changelog/3.0.0/ for details
- Remove aegisub-2.1.9-system_libs.patch, aegisub-2.1.8.99.rev5789-ld.patch
  and aegisub-2.1.9-underlinking.patch. Fixed upstream.
- Update aegisub-2.1.9-no_glu.patch to aegisub-3.0.0-no_glu.patch
- Add aegisub-3.0.0-docdir.patch
- Build only the two relevant audio output backends: ALSA and PulseAudio
- The scripting system no longer supports Perl and Ruby, remove BuildRequires
* Fri Sep 21 2012 reddwarf@opensuse.org
- Add aegisub-2.1.9-no_glu.patch
- Remove explicit glu dependency.
  wxWidgets-devel is the one that should have it
- Remove explicit xfixes,xdamage and xxf86vm dependencies.
  Mesa-libGL-devel is the one that should be fixed (probably removing the .la file)
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu,xfixes,xdagame and xxf86vm dependency
* Fri Feb 10 2012 reddwarf@opensuse.org
- Update to 2.1.9
* Sat Oct 29 2011 reddwarf@opensuse.org
- Update to 2.1.9 rev5789
* Sun Jul  5 2009 reddwarf@opensuse.org
- First package
